==> developer-center-api-3.5.64-20200724.023946-8-sources.jar: cn/com/duiba/developer/center/api/domain/paramquery/survey/SurveyQueryParam.java <==
package cn.com.duiba.developer.center.api.domain.paramquery.survey;

import cn.com.duiba.developer.center.api.domain.enums.survey.ChannelTypeEnum;
import cn.com.duiba.developer.center.api.domain.enums.survey.LabelEnum;
import cn.com.duiba.developer.center.api.domain.enums.survey.SurveyStatusEnum;
import cn.com.duiba.developer.center.api.domain.paramquery.PageQueryParam;

import javax.validation.constraints.Min;

public class SurveyQueryParam extends PageQueryParam {
    private Integer total;

    private Integer type = 1;
    /**
     * 标题C端名称
     */
    private String title;
    /**
     * B端名称
     */
    private String name;

    /**
     * 标签
     * {@link LabelEnum}
     */
    private String label;

    /**
     * 状态
     * {@link SurveyStatusEnum}
     */
    private Integer status;

    /**
     * 渠道类型/场景类型
     * {@link ChannelTypeEnum}
     */
    private Integer channelType;

    /**
     * 渠道类型/场景类型/活动Id
     */
    @Min(value = 0, message = "场景值不合法")
    private Long activityId;

    /**
     * 活动名称
     */
    private String activityName;

    /**
     * appId
     */
    private Long appId;

    private String appName;

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getLabel() {
        return label;
    }

    public void setLabel(String label) {
        this.label = label;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getChannelType() {
        return channelType;
    }

    public void setChannelType(Integer channelType) {
        this.channelType = channelType;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public Integer getTotal() {
        return total;
    }

    public void setTotal(Integer total) {
        this.total = total;
    }
}

==> developer-center-api-3.9.18-sources.jar: cn/com/duiba/developer/center/api/domain/paramquery/survey/SurveyQueryParam.java <==
package cn.com.duiba.developer.center.api.domain.paramquery.survey;

import cn.com.duiba.developer.center.api.domain.enums.survey.ChannelTypeEnum;
import cn.com.duiba.developer.center.api.domain.enums.survey.LabelEnum;
import cn.com.duiba.developer.center.api.domain.enums.survey.SurveyStatusEnum;
import cn.com.duiba.developer.center.api.domain.paramquery.PageQueryParam;

import java.util.Date;

public class SurveyQueryParam extends PageQueryParam {
    private Integer total;

    private Integer type = 1;
    /**
     * 标题C端名称
     */
    private String title;
    /**
     * B端名称
     */
    private String name;

    /**
     * 标签
     * {@link LabelEnum}
     */
    private String label;

    /**
     * 状态
     * {@link SurveyStatusEnum}
     */
    private Integer status;

    /**
     * 渠道类型/场景类型
     * {@link ChannelTypeEnum}
     */
    private Integer channelType;

    /**
     * 渠道类型/场景类型/活动Id
     */
    private String activityId;

    /**
     * 活动名称
     */
    private String activityName;

    /**
     * appId
     */
    private Long appId;

    private String appName;

    /**
     * 开始、结束日期
     */
    private Date startDate;

    private Date endDate;

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getLabel() {
        return label;
    }

    public void setLabel(String label) {
        this.label = label;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Integer getChannelType() {
        return channelType;
    }

    public void setChannelType(Integer channelType) {
        this.channelType = channelType;
    }

    public String getActivityId() {
        return activityId;
    }

    public void setActivityId(String activityId) {
        this.activityId = activityId;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public Integer getTotal() {
        return total;
    }

    public void setTotal(Integer total) {
        this.total = total;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
}
